==> notolog-0.9.1b3.tar.gz: notolog-0.9.1b3/notolog/lexemes/tr/settings_dialog.py <==
# Turkish lexemes settings_dialog.py
lexemes = {
    "window_title": "Ayarlar",

    "button_close": "Kapat",

    "tab_general": "Genel",
    "tab_editor_config": "Editör",
    "tab_viewer_config": "Görüntüleyici",
    "tab_ai_config": "AI Ayarları",

    "general_app_config_label": "Uygulama ayarları",
    "general_app_language_label": "Dil",
    "general_app_language_combo_placeholder_text": "Bir dil seçin",
    "general_app_language_combo_accessible_description": "Uygulamanın arayüz dili",
    "general_app_theme_label": "Tema",
    "general_app_theme_combo_placeholder_text": "Bir tema seçin",
    "general_app_theme_combo_accessible_description": "Uygulamanın arayüz teması",
    "general_app_main_menu_label": "Ana Menü",
    "general_app_main_menu_checkbox": "Ana Menüyü Göster",
    "general_app_main_menu_checkbox_accessible_description": "Uygulamanın ana açılır menüsünü göster",
    "general_app_font_size_label": "Yazı Boyutu: {size}pt",
    "general_app_font_size_slider_accessible_description": "Uygulamanın genel yazı boyutunu ayarlayın",

    "general_statusbar_label": "Durum Çubuğu",
    "general_statusbar_show_global_cursor_position_checkbox": "Genel İmleç Pozisyonunu Göster",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "Durum çubuğunda genel imleç pozisyonunu göster",

    "editor_config_label": "Editör Yapılandırması",
    "editor_config_show_line_numbers_checkbox": "Satır Numaralarını Göster",
    "editor_config_show_line_numbers_checkbox_accessible_description": "Editörde satır numaralarını göster",

    "viewer_config_label": "Görüntüleyici Yapılandırması",
    "viewer_config_process_emojis_checkbox": "Metin Emojilerini Grafiklere Dönüştür",
    "viewer_config_process_emojis_checkbox_accessible_description": "Metin emojilerini grafiksel temsillere dönüştür",
    "viewer_config_highlight_todos_checkbox": "TODO'ları Vurgula",
    "viewer_config_highlight_todos_checkbox_accessible_description": "Metindeki TODO etiketlerini vurgula",
    "viewer_config_open_link_confirmation_checkbox": "Bağlantıları Açmadan Önce Onay İste",
    "viewer_config_open_link_confirmation_checkbox_accessible_description": "Bağlantıları açmadan önce onay isteyin",
    "viewer_config_save_resources_checkbox": "Dış Resimleri Diskte Otomatik Kaydet",
    "viewer_config_save_resources_checkbox_accessible_description":
        "Dış resimlerin kopyalarını çevrimdışı erişim için diske otomatik olarak kaydet",

    "ai_config_openai_api_label": "OpenAI API",
    "ai_config_openai_api_url_input_placeholder_text": "API URL",
    "ai_config_openai_api_url_input_accessible_description": "OpenAI API URL'si",
    "ai_config_openai_api_key_input_placeholder_text": "API anahtarı",
    "ai_config_openai_api_key_input_accessible_description": "OpenAI API anahtarı",
    "ai_config_openai_api_supported_models_label": "Desteklenen modeller",
    "ai_config_ai_model_names_combo_placeholder_text": "Model seç",
    "ai_config_ai_model_names_combo_accessible_description": "Seçilebilecek desteklenen modeller",

    "ai_config_base_label": "Temel Parametreler",
    "ai_config_base_system_prompt_label": "Sistem İstemcisi",
    "ai_config_base_system_prompt_edit_placeholder_text": "Her istekten önce gelen temel sistem istemcisi",
    "ai_config_base_system_prompt_edit_accessible_description":
        "Her istekten önce gelen temel sistem istemcisi. Bu düz metindir.",
    "ai_config_base_response_max_tokens_label": "Maksimum Yanıt Token'ları",
    "ai_config_base_response_max_tokens_input_accessible_description": "Yanıtta alınabilecek maksimum token sayısı",
}

==> notolog-1.1.5.tar.gz: notolog-1.1.5/notolog/lexemes/tr/settings_dialog.py <==
# Turkish lexemes settings_dialog.py
lexemes = {
    # Ayarlar
    "window_title": "Ayarlar",

    "button_close": "Kapat",

    "tab_general": "Genel",
    "tab_editor_config": "Editör",
    "tab_viewer_config": "Görüntüleyici",
    "tab_ai_config": "AI Ayarları",

    "general_app_config_label": "Uygulama ayarları",
    "general_app_language_label": "Dil",
    "general_app_language_combo_placeholder_text": "Bir dil seçin",
    "general_app_language_combo_accessible_description": "Uygulamanın arayüz dili",
    "general_app_theme_label": "Tema",
    "general_app_theme_combo_placeholder_text": "Bir tema seçin",
    "general_app_theme_combo_accessible_description": "Uygulamanın arayüz teması",
    "general_app_default_path_label": "Notlar için varsayılan klasör",
    "general_app_default_path_input_accessible_description": "Notların saklanacağı varsayılan klasörü belirtin",
    "general_app_default_path_input_placeholder_text": "Bir klasör yolu seçin veya girin",
    "general_app_elements_visibility_label": "Öğelerin görünürlüğünü yönet",
    "general_app_main_menu_label": "Ana Menü",
    "general_app_main_menu_checkbox": "Ana Menüyü Göster",
    "general_app_main_menu_checkbox_accessible_description": "Uygulamanın ana açılır menüsünü göster",
    "general_app_font_size_label": "Yazı Boyutu: {size}pt",
    "general_app_font_size_slider_accessible_description": "Uygulamanın genel yazı boyutunu ayarlayın",

    "general_statusbar_label": "Durum Çubuğu",
    "general_statusbar_show_global_cursor_position_checkbox": "Genel İmleç Pozisyonunu Göster",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "Durum çubuğunda genel imleç pozisyonunu göster",
    "general_statusbar_show_navigation_arrows_checkbox": "Gezinme oklarını göster",
    "general_statusbar_show_navigation_arrows_checkbox_accessible_description":
        "Durum çubuğunda gezinme oklarını göster",

    "editor_config_label": "Editör Yapılandırması",
    "editor_config_show_line_numbers_checkbox": "Satır Numaralarını Göster",
    "editor_config_show_line_numbers_checkbox_accessible_description": "Editörde satır numaralarını göster",

    "viewer_config_label": "Görüntüleyici Yapılandırması",
    "viewer_config_process_emojis_checkbox": "Metin Emojilerini Grafiklere Dönüştür",
    "viewer_config_process_emojis_checkbox_accessible_description": "Metin emojilerini grafiksel temsillere dönüştür",
    "viewer_config_highlight_todos_checkbox": "TODO'ları Vurgula",
    "viewer_config_highlight_todos_checkbox_accessible_description": "Metindeki TODO etiketlerini vurgula",
    "viewer_config_open_link_confirmation_checkbox": "Bağlantıları Açmadan Önce Onay İste",
    "viewer_config_open_link_confirmation_checkbox_accessible_description": "Bağlantıları açmadan önce onay isteyin",
    "viewer_config_save_resources_checkbox": "Dış Resimleri Diskte Otomatik Kaydet",
    "viewer_config_save_resources_checkbox_accessible_description":
        "Dış resimlerin kopyalarını çevrimdışı erişim için diske otomatik olarak kaydet",

    "ai_config_inference_module_label": "Çıkarım Modülü",
    "ai_config_inference_module_names_combo_label": "Aktif Çıkarım Modülü",
    "ai_config_inference_module_names_combo_placeholder_text": "Modül Seçin",
    "ai_config_inference_module_names_combo_accessible_description":
        "AI Asistanı ile çalışacak mevcut AI çıkarım modüllerinden seçim yapın.\n"
        "Seçenekler, gerçek zamanlı işleme sahip büyük dil modelleri (LLM) veya API tabanlı işlevselliği içerir.",

    "ai_config_base_label": "Temel Parametreler",
    "ai_config_multi_turn_dialogue_checkbox": "Konuşma hafızasına sahip çok dönüşlü diyalog",
    "ai_config_multi_turn_dialogue_checkbox_accessible_description":
        "Konuşma hafızası için önceki istemi koruyan çok dönüşlü diyaloğu etkinleştirin.\n"
        "Devre dışı bırakıldığında, yalnızca yeni mesaj ve sistem istemi yanıtı etkiler.",
    "ai_config_convert_to_md_checkbox": "Sonucu Markdown'a Dönüştür",
    "ai_config_convert_to_md_checkbox_accessible_description":
        "Çıkış mesajını Markdown formatına dönüştürün.",
}
